#include <stdio.h>
#include <ctype.h>
#include <stdint.h>
#include <string.h>
#include <stdlib.h>
#include <stdbool.h>
#include <getopt.h>
#include "AwFmIndex.h"
#include <sys/stat.h>
#include <FastaVector.h>
char fullGenomeFile[1024] = "";

//int64_t getFullGenomeFromFasta(char *fastaFileSrc, char *buffer);
//int64_t getChromosomeFromFullFasta(char *fastaFileSrc, int chromosomeNumber, char *buffer);
//void buildChromosomeIndex(int chromosomeNumber, uint8_t suffixArrayCompressionRatio, uint8_t kmerLengthInSeedTable, char *indexFilename);
//void buildFullGenomeIndex(uint8_t suffixArrayCompressionRatio, uint8_t kmerLengthInSeedTable, char *indexFilename);
void buildIndex(const uint8_t suffixArrayCompressionRatio, const uint8_t seedTableLength, char *fastaFileSrc, char *indexFileSrc);
size_t readFastaFile(const char *fastaFileSrc, char **bufferOut);
void parseArgs(int argc, char **argv);

//parameters

bool isAminoSequence;
int chromosomeNumber;
bool chromosomeNumberSetInArgs;
bool fullGenomeIndexRequested;
int suffixArrayCompressionRatio;
int kmerLengthInSeedTable;
bool kmerLengthSetInArgs;
char indexFilenameBuffer[1024];
char fastaFileSrc[1024];

int main(int argc, char **argv){
  //default parameters
  strcpy(indexFilenameBuffer, "index.awfmi");
  isAminoSequence             = false;
  suffixArrayCompressionRatio = 4;
  kmerLengthInSeedTable       = 12;
  kmerLengthSetInArgs         = false;
  parseArgs(argc, argv);
  printf("parse finished: isAmino %i, sacr %i, klist %i\n",
    isAminoSequence, suffixArrayCompressionRatio, kmerLengthInSeedTable);

  //set the kmer length in seed table based on the alphabet type, if not specified.
  if(!kmerLengthSetInArgs){
    kmerLengthInSeedTable = isAminoSequence? 12: 5;
  }
  buildIndex(suffixArrayCompressionRatio, kmerLengthInSeedTable, fastaFileSrc, indexFilenameBuffer);
}


void parseArgs(int argc, char **argv){
  int option = 0;
  while((option = getopt(argc, argv, "as:k:f:i:")) != -1){
    switch(option){
      case 'a':
        isAminoSequence = true;
        break;
      case 's':
        sscanf(optarg, "%i", &suffixArrayCompressionRatio);
        break;
      case 'k':
        sscanf(optarg, "%i", &kmerLengthInSeedTable);
        kmerLengthSetInArgs = true;
	break;
      case 'i':
        strcpy(indexFilenameBuffer, optarg);
        break;
      case 'f':
        strcpy(fastaFileSrc, optarg);
        break;
    }
  }
}



void buildIndex(const uint8_t suffixArrayCompressionRatio, const uint8_t seedTableLength, char *fastaFileSrc, char *indexFileSrc){
  printf("reading fasta file...\n");
  char *buffer;
  size_t sequenceLength = readFastaFile(fastaFileSrc, &buffer);

  struct AwFmIndex *index;
printf("%zu\n", sizeof(struct AwFmIndexConfiguration));
  enum AwFmAlphabetType alphabet = isAminoSequence? AwFmAlphabetAmino: AwFmAlphabetNucleotide;
  struct AwFmIndexConfiguration config = {.suffixArrayCompressionRatio=suffixArrayCompressionRatio,
    .kmerLengthInSeedTable=seedTableLength, .alphabetType=alphabet, .storeOriginalSequence=false};
  
  printf("building index...\n");
  enum AwFmReturnCode returnCode = awFmCreateIndex(&index, &config, (uint8_t*)buffer, sequenceLength, indexFileSrc, true);
  if(returnCode < 0){
    printf("Error: awFmCreateIndex returned error code %i. please refer to AwFmIndex.h in the github repo for more info on this return code.", returnCode);
    exit(-1);
  }

  printf("index created at %s, deallocating...\n", indexFileSrc);
  awFmDeallocIndex(index);
  free(buffer);
}


size_t readFastaFile(const char *fastaFileSrc, char **bufferOut){
  printf("reading fasta \n");
  struct stat fileStats;
  stat(fastaFileSrc, &fileStats);

  char *buffer = malloc((fileStats.st_size + 1024) * sizeof(char)); //adding 1024 here just to guard against buffer overflow nonsense.
  FILE *file = fopen(fastaFileSrc, "r");
  if(!file){
    printf("Error: could not open file %s\n", fastaFileSrc);
    exit(-1);
  }

  size_t sequenceLength = 0;
  int prevPercent = -1;
  printf("\n");
  while(!feof(file) && !ferror(file)){

    int percentComplete =(int)((sequenceLength * 100) / fileStats.st_size);
    if(percentComplete > prevPercent){  
      printf("loading fasta file [%i%%]\r", percentComplete);
      prevPercent = percentComplete;
    }
    
    fgets(buffer+sequenceLength, 1024, file);
    //if this line starts with a letter
    if(buffer[sequenceLength]>='A'){
      sequenceLength += strlen(buffer+sequenceLength);

      //check for and remove newlines at the end of the buffer.
      while(buffer[sequenceLength-1] < 'A'){
       // printf("found garbage char %u\n", buffer[sequenceLength-1]);
        sequenceLength--;
      }
    }
  }

  printf("loading fasta file [100%%]\n");
  fclose(file);
 *bufferOut = buffer;
  return sequenceLength;
}

