#include <stdio.h>
#include <ctype.h>
#include <stdint.h>
#include <string.h>
#include <stdlib.h>
#include <stdbool.h>
#include <getopt.h>
#include <time.h>
#include <sys/time.h>
#include <stddef.h>
#include "AwFmIndex.h"


#define RETURN_CODE_COULD_NOT_READ_KMER_FILE  -10

char indexFilenameBuffer[128];

char *nucQueryBuffer = "TATCTCTGACACGT";
char *aminoQueryBuffer = "GAFFPQ";
bool useCountFunction;
bool isAmino = false;
bool keepSuffixArrayInMemory;
const uint8_t numQueries = 1;
const uint8_t numThreads = 1;
void parseArgs(int argc, char **argv);

int main(int argc, char **argv){
  //set default parameters
  strcpy(indexFilenameBuffer, "index.awfmi");
  useCountFunction = false;
  keepSuffixArrayInMemory=true;
  parseArgs(argc, argv);

  struct AwFmIndex *index;
  enum AwFmReturnCode returnCode = awFmReadIndexFromFile(&index, indexFilenameBuffer, keepSuffixArrayInMemory);
  if(returnCode < 0){
    printf("Error during index read: awFmReadIndexFromFile returned error code %i\n", returnCode);
    exit(-1);
  }

  struct AwFmKmerSearchList *searchList = awFmCreateKmerSearchList(numQueries);
  if(searchList == NULL){
    printf("Error: could not allocate memory for the search data struct.\n");
    exit(-2);
  }
  if(isAmino){
    searchList->kmerSearchData[0].kmerString = aminoQueryBuffer;
    searchList->kmerSearchData[0].kmerLength = 6;
  }
  else{
    searchList->kmerSearchData[0].kmerString = nucQueryBuffer; 
    searchList->kmerSearchData[0].kmerLength = 14;
  }


  size_t countTotal = 0;
  for(size_t i = 0; i < 4; i++){	//comment this line out (and uncomment the for loop a couple dozen lines up) to generate unique query sets for each test.
    if(useCountFunction){
      awFmParallelSearchCount(index, searchList, numThreads);
    }
    else{
      awFmParallelSearchLocate(index, searchList, numThreads);
    }

    countTotal += searchList->kmerSearchData[0].count;
  }

  double averageCountPerKmer = (double)countTotal / (double)(4);
  printf("avg # hits = %f\n", averageCountPerKmer);

  //deallocate the query strings.
  awFmDeallocKmerSearchList(searchList);
  awFmDeallocIndex(index);
}


void parseArgs(int argc, char **argv){
  int option = 0;
  while((option = getopt(argc, argv, "mcdai:")) != -1){
    //printf("option: %c ", option);
    switch(option){
      case 'm':
        keepSuffixArrayInMemory = true;
        break;
      case 'd':
        keepSuffixArrayInMemory=false;
	break;
      case 'c':
        useCountFunction = true;
        break;
      case 'i':
        strcpy(indexFilenameBuffer, optarg);
        break;
      case 'a':
        isAmino = true;
        break;
    }
  }
}

