#!/bin/sh

NUC_FASTA_LEN=2000000000
AMINO_FASTA_LEN=2000000000
NUC_FASTA_SRC="bigNuc.fasta"
#AMINO_FASTA_SRC="amino.fasta"

NUC_SEQAN_INDEX_SRC="bigSeqanNucIndex.index"
AMINO_SEQAN_INDEX_SRC="bigSeqanAminoIndex.index"

NUC_AWFMI_INDEX_SRC="bigAwfmiNucIndex.awfmi"
AMINO_AWFMI_INDEX_SRC="bigAwfmiAminoIndex.awfmi"

DEFAULT_NUC_QUERY_TABLE_LENGTH=12
DEFAULT_AMINO_QUERY_TABLE_LENGTH=5
DEFAULT_SUFFIX_ARRAY_COMPRESSION_RATIO=4

build=1


if [ $build -eq "1" ]
then
  echo "generating random sequences..."
  ./esl-shuffle -G -o _bigNuc1.fasta -L $NUC_FASTA_LEN -N 1 --dna
  ./esl-shuffle -G -o _bigNuc2.fasta -L $NUC_FASTA_LEN -N 1 --dna
  ./esl-shuffle -G -o _bigNuc3.fasta -L $NUC_FASTA_LEN -N 1 --dna
  
  ./esl-shuffle -G -o _big1Amino.fasta -L $AMINO_FASTA_LEN -N 1 --amino
  ./esl-shuffle -G -o _big2Amino.fasta -L $AMINO_FASTA_LEN -N 1 --amino
  ./esl-shuffle -G -o _big3Amino.fasta -L $AMINO_FASTA_LEN -N 1 --amino
  
  echo ">bigIndex" > bigNuc.fasta
  echo ">bigIndex" > bigAmino.fasta

  awk 'FNR>1' _bigNuc1.fasta _bigNuc2.fasta _bigNuc3.fasta >> bigNuc.fasta
  awk 'FNR>1' _big1Amino.fasta _big2Amino.fasta _big3Amino.fasta >> bigAmino.fasta
  ./esl-shuffle -G -o $AMINO_FASTA_SRC -L $AMINO_FASTA_LEN -N 1 --amino
  
  echo "building indices..."
  #build the sequan3 index
  seqan3/seqanIndex.out -b -f bigNuc.fasta -i $NUC_SEQAN_INDEX_SRC
  seqan3/seqanIndex.out -b -a -f bigAmino.fasta -i $AMINO_SEQAN_INDEX_SRC
  
  awfmi/build/buildIndex.out -f bigNuc.fasta -i $NUC_AWFMI_INDEX_SRC -k $DEFAULT_NUC_QUERY_TABLE_LENGTH -s $DEFAULT_SUFFIX_ARRAY_COMPRESSION_RATIO 
  awfmi/build/buildIndex.out -a -f bigAmino.fasta -i $AMINO_AWFMI_INDEX_SRC -k $DEFAULT_AMINO_QUERY_TABLE_LENGTH -s $DEFAULT_SUFFIX_ARRAY_COMPRESSION_RATIO
  
  echo "indices built, running memtests"  
fi

echo "------awfmi nuc mem data------"
(/usr/bin/time -v awfmi/memtest/awfmiMemtest.out -i $NUC_AWFMI_INDEX_SRC) &> big_nuc_index_awfmi.txt
echo "------awfmi amino mem data------"
(/usr/bin/time -v awfmi/memtest/awfmiMemtest.out -i $AMINO_AWFMI_INDEX_SRC) &> big_amino_index_awfmi.txt
echo "------seqan nuc mem data------"
(/usr/bin/time -v seqan3/seqanMemtest/seqanMemtest.out -i $NUC_SEQAN_INDEX_SRC) &> big_nuc_index_seqan.txt
echo "------ seqan amino mem data------"
(/usr/bin/time -v seqan3/seqanMemtest/seqanMemtest.out -i $AMINO_SEQAN_INDEX_SRC) &> big_amino_index_seqan.txt

#  display the file sizes of the 4 indices
#AWFMI_NUC_BIG_INDEX_FILE_SIZE=`ls -s | grep $NUC_AWFMI_INDEX_SRC`
#AWFMI_AMINO_BIG_INDEX_FILE_SIZE=`ls -s | grep $AMINO_AWFMI_INDEX_SRC`
#SEQAN_NUC_BIG_INDEX_FILE_SIZE=`ls -s | grep $NUC_SEQAN_INDEX_SRC`
#SEQAN_AMINO_BIG_INDEX_FILE_SIZE=`ls -s | grep $AMINO_SEQAN_INDEX_SRC`

#echo "awfmi 6Gbp nuc file size in bytes $AWFMI_NUC_BIG_INDEX_FILE_SIZE"
#echo "seqan 6Gbp nuc file size in bytes $SEQAN_NUC_BIG_INDEX_FILE_SIZE"

#echo "seqan 6Gig positon amino file size in bytes $SEQAN_AMINO_BIG_INDEX_FILE_SIZE"
#echo "awfmi 6Gig position amino file size in bytes $AWFMI_AMINO_BIG_INDEX_FILE_SIZE"

rm _bigNuc1.fasta _bigNuc2.fasta _bigNuc3.fasta _big1Amino.fasta _big2Amino.fasta _big3Amino.fasta
