#!/bin/sh

NUC_FASTA_LEN=1000000000
AMINO_FASTA_LEN=200000000
NUC_FASTA_SRC="nuc.fasta"
AMINO_FASTA_SRC="amino.fasta"

NUC_SEQAN_INDEX_SRC="seqanNucIndex.index"
AMINO_SEQAN_INDEX_SRC="seqanAminoIndex.index"

NUC_AWFMI_INDEX_SRC="awfmiNucIndex.awfmi"
AMINO_AWFMI_INDEX_SRC="awfmiAminoIndex.awfmi"

DEFAULT_NUC_QUERY_TABLE_LENGTH=12
DEFAULT_AMINO_QUERY_TABLE_LENGTH=5
DEFAULT_SUFFIX_ARRAY_COMPRESSION_RATIO=4

BUILD_NEW_FASTAS=1
BUILD_SEQAN=1
BUILD_AWFMI=1


#(cd seqan3 && make )

if [ $BUILD_NEW_FASTAS -eq "1" ]
then
	echo "generating random sequences..."
	./esl-shuffle -G -o $NUC_FASTA_SRC -L $NUC_FASTA_LEN -N 1 --dna
	./esl-shuffle -G -o $AMINO_FASTA_SRC -L $AMINO_FASTA_LEN -N 1 --amino
fi

echo "building indices..."
#build the sequan3 index

if [ $BUILD_SEQAN -eq "1" ]
then
	seqan3/seqanIndex.out -b -f $NUC_FASTA_SRC -i $NUC_SEQAN_INDEX_SRC
	seqan3/seqanIndex.out -b -a -f $AMINO_FASTA_SRC -i $AMINO_SEQAN_INDEX_SRC
fi

if [ $BUILD_AWFMI -eq "1" ]
then
	awfmi/build/buildIndex.out -f $NUC_FASTA_SRC -i $NUC_AWFMI_INDEX_SRC -k $DEFAULT_NUC_QUERY_TABLE_LENGTH -s 4 
	awfmi/build/buildIndex.out -a -f $AMINO_FASTA_SRC -i $AMINO_AWFMI_INDEX_SRC -k $DEFAULT_AMINO_QUERY_TABLE_LENGTH -s 4
fi


echo "indices built."
