#!/bin/sh

#produces the data for figure 4 in the paper, specifically the index with kmer table length of 1 and the data associated with it (blue lines). 
NUC_FASTA_SRC="nuc.fasta"
NUC_K1_INDEX_SRC="awfmiNuc_k1Index.awfmi"
REGULAR_INDEX_SRC="awfmiNucIndex.awfmi"
NUM_THREADS=1
NUM_QUERIES=1000000

echo "making data for figure 4: index with kmer table len 1."

#create the index with k=1 for the kmer table if it doesn't exist.
if [ ! -f $NUC_K1_INDEX_SRC ]; then
  awfmi/build/buildIndex.out -f $NUC_FASTA_SRC -i $NUC_K1_INDEX_SRC -s 4 -k 1
fi


#generate the table data
for queryLength in 11 12 13 14 15 16 17 18 19 20
do
  echo "----------------------data for Fig 4, Count(), table length 1, query length $queryLength----------------"
  awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $queryLength -i $NUC_K1_INDEX_SRC -t $NUM_THREADS -n $NUM_QUERIES -c | grep "average"| awk '{print $9}'
done

for queryLength in 11 12 13 14 15 16 17 18 19 20
do
  echo "----------------------data for Locate(), table length 1, query length $queryLength----------------"
  awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $queryLength -i $NUC_K1_INDEX_SRC -t $NUM_THREADS -n $NUM_QUERIES | grep "average"| awk '{print $9}'

done

for queryLength in 11 12 13 14 15 16 17 18 19 20
do
  echo "----------------------data for Fig 4, Count(), regular index, query length $queryLength----------------"
  awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $queryLength -i $REGULAR_INDEX_SRC -t $NUM_THREADS -n $NUM_QUERIES -c | grep "average"| awk '{print $9}'
done

for queryLength in 11 12 13 14 15 16 17 18 19 20
do
  echo "----------------------data for Fig 4, Locate(), regular index, query length $queryLength----------------"
  awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $queryLength -i $REGULAR_INDEX_SRC -t $NUM_THREADS -n $NUM_QUERIES | grep "average" | awk '{print $9}'
done
