#!/bin/sh

NUM_QUERIES=1000000
NUC_SEQAN_INDEX_SRC="seqanNucIndex.index"
AMINO_SEQAN_INDEX_SRC="seqanAminoIndex.index"
NUC_AWFMI_INDEX_SRC="awfmiNucIndex.awfmi"
AMINO_AWFMI_INDEX_SRC="awfmiAminoIndex.awfmi"
NUM_THREADS=1
NUC_QUERY_LENGTH=14
AMINO_QUERY_LENGTH=6
DEFAULT_NUC_KMER_TABLE_LENGTH=12
DEFAULT_AMINO_KMER_TABLE_LENGTH=5
#NUC_FASTA_SRC="bigNuc.fasta"
#AMINO_FASTA_SRC="bigAmino.fasta"
NUC_FASTA_SRC="nuc.fasta"
AMINO_FASTA_SRC="amino.fasta"


cd seqan3 && ./makeAll.sh && cd ..
cd seqan3/memtest && ./makeAll.sh && cd ../..

echo "making suffix array compression ratio data..."
for compressionRatio in 1 2 4 8 16 32 64 128
do
  echo "---------------------suffix array compression ratio $compressionRatio --------------"  
  SEQAN_EXE_LOCAL_FILE=seqanSa${compressionRatio}.out
  SEQAN_EXE_FILE=seqan3/$SEQAN_EXE_LOCAL_FILE
  cd seqan3 && make BIN=$SEQAN_EXE_LOCAL_FILE SA_SAMPLING_RATE=$compressionRatio && cd ..
  SEQAN_MEMTEST_LOCAL_EXE=seqanSa${compressionRatio}.out
  SEQAN_MEMTEST_EXE=seqan3/seqanMemtest/$SEQAN_MEMTEST_LOCAL_EXE
  cd seqan3/seqanMemtest && make BIN=$SEQAN_MEMTEST_LOCAL_EXE SA_SAMPLING_RATE=$compressionRatio && cd ../..


  INDEX_FILE_SRC="saTest_se${compressionRatio}.index"
  #build and benchmark seqan3 nucleotide
  echo "Building Seqan3 Nuc"
  $SEQAN_EXE_FILE -b -f $NUC_FASTA_SRC -i $INDEX_FILE_SRC  
  echo "Seqan3, Nuc Locate() time:"
  $SEQAN_EXE_FILE -f $NUC_FASTA_SRC -k $NUC_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES | grep "average"
#  echo "file size for seqan nuc"
#  ls -al $INDEX_FILE_SRC  
  /usr/bin/time -v $SEQAN_MEMTEST_EXE -i $INDEX_FILE_SRC | grep "Maximum Resident"
  rm $INDEX_FILE_SRC
  
  #build and benchmark seqan3 amino acid
  $SEQAN_EXE_FILE -b -a -f $AMINO_FASTA_SRC -i $INDEX_FILE_SRC 
  echo "Seqan3, AA Locate() time::"
  $SEQAN_EXE_FILE -f $AMINO_FASTA_SRC -k $AMINO_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES -a | grep "average"
  
#  echo "file size for seqan amino"
#  ls -al $INDEX_FILE_SRC

  /usr/bin/time -v $SEQAN_MEMTEST_EXE -a -i $INDEX_FILE_SRC | grep "Maximum Resident"
  rm $INDEX_FILE_SRC

  #build and benchmark awfmi 
  INDEX_FILE_SRC="saTest_aw_nuc.awfmi"
  awfmi/build/buildIndex.out -f $NUC_FASTA_SRC -i $INDEX_FILE_SRC -s $compressionRatio -k $DEFAULT_NUC_KMER_TABLE_LENGTH 
  awfmi/memtest/awfmiMemtest.out -i $INDEX_FILE_SRC


  echo "awfmi Nuc in memory Locate() time:"
echo "awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $NUC_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES"
  awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $NUC_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES | grep "average"
  echo "awfmi Nuc on disk Locate() time:"
  awfmi/search/awfmiSearch.out -f $NUC_FASTA_SRC -k $NUC_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES -d | grep "average"
  
#  echo "file size for awfmi nuc"
#  ls -al $INDEX_FILE_SRC        
  awfmi/memtest/awfmiMemtest.out -i $INDEX_FILE_SRC
  echo "memory for AWFMI nuc compression ratio $compressionRatio"
  /usr/bin/time -v awfmi/memtest/awfmiMemtest.out -i $INDEX_FILE_SRC | grep "Maximum Resident"
  rm $INDEX_FILE_SRC


  awfmi/build/buildIndex.out -a -f $AMINO_FASTA_SRC -i $INDEX_FILE_SRC -s $compressionRatio -k $DEFAULT_AMINO_KMER_TABLE_LENGTH 
  echo "awfmi AA in memory Locate() time:"
  awfmi/search/awfmiSearch.out -f $AMINO_FASTA_SRC -k $AMINO_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES | grep "average"
  echo "awfmi AA on disk Locate() time:"
  awfmi/search/awfmiSearch.out -f $AMINO_FASTA_SRC -k $AMINO_QUERY_LENGTH -i $INDEX_FILE_SRC -t 1 -n $NUM_QUERIES -d | grep "average"
  
#  echo "file size for awfmi amino"
#  ls -al $INDEX_FILE_SRC          
  
  echo "memory usage for AWFMI amino compression ratio $compressionRatio"
  /usr/bin/time -v awfmi/memtest/awfmiMemtest.out -i $INDEX_FILE_SRC -a | grep "Maximum Resident"
  rm $INDEX_FILE_SRC

done



